(package-initialize)

(defun pkg-description (package)
  "Return the description for PACKAGE.
    If PACKAGE is installed, the will be present on `package-alist',
    otherwise look for it in `package-archive-contents'."
  (or (cadr (assoc package package-alist))
      (cadr (assoc package package-archive-contents))))

(defun pkg-ensure-archive (package)
  "Install PACKAGE from the archives, if not already installed."
  (when-let ((pkg-desc (pkg-description package)))
    (unless (package-installed-p pkg-desc)
      (package-install-from-archive pkg-desc))))

(defun require-package (package &optional force)
  "Ensure that PACKAGE is installed.
    If FORCE is non-nil, force installation regardless if PACKAGE is
    built-in or not.

    First, use `package-installed-p' to check if PACKAGE was
    installed via the Emacs package manager, otherwise, try to
    `require' PACKAGE; this ensures that we don't require PACKAGE if
    it was installed using the package manager. If both of those
    fail, run `package-refresh-contents' and install PACKAGE."
  (unless (and (not force)
               (or (package-installed-p package)
                   (require package nil 'no-error)))
    (unless (assoc package package-archive-contents)
      (package-refresh-contents))
    (if force
        (pkg-ensure-archive package)
      (package-install package))))

(require-package 'org :force)
